% neuron parameters
Vreset = -70.0;  %mV
Vth = -55.0;  %mV
Cm = 250.0;  %pF

% simulation parameters
simtime = 5.0;  %s
sampling_time = 0.001;  %s
samples = round(simtime/sampling_time);
t = (1:samples)*sampling_time;

% external input current (pA)
% constant current
Iext = 5000.0*ones(samples, 1);  %pA
% Iext(501:end) = 2*Iext(501:end);

% sinusoidal current
% Iext = 50*sin(t)+50;



% membrane potential
Vm = zeros(samples, 1);  %mV
Vm(1) = Vreset;

%simulation
spikes = [];
for i=2:samples
    dVm = Iext(i)/Cm; %V/s
    Vm(i) = Vm(i-1)+dVm; % * 1 mV
    
    % spike
    if (Vm(i) > Vth)
        Vm(i) = Vreset;
        spikes = [spikes t(i)];
    end
    
end


% plotting
figure
if (~isempty(spikes))
    subplot(2, 1, 1);
end

plot(t, Vm);
xlabel('time (s)');
ylabel('V_m (mV)');
hold all;
plot(t, (Iext-min(Iext))/(max(Iext)-min(Iext))*(max(Vm)-min(Vm))+min(Vm));
hold off;

if (~isempty(spikes))
    subplot(2, 1, 2);
    LineFormatVert.LineWidth = 0.35;
    plotSpikeRaster({spikes}, ...
                    'PlotType', 'vertline', ...
                    'LineFormat', LineFormatVert, ...
                    'VertSpikePosition', -0.5, ...
                    'TimePerBin', 0.001, ...
                    'VertSpikeHeight', 0.7);
    xlabel('time (s)');
    xlim([0 simtime]);
end