% neuron parameters
Vreset = -70.0;  %mV
Vth = -55.0;  %mV
Cm = 250.0;  %pF
tref = 2.0;  %ms

% simulation parameters
simtime = 0.2;  %s
sampling_time = 0.001;  %s
samples = round(simtime/sampling_time);
t = (1:samples)*sampling_time;

% external input current (pA)
% Iext = 5000.0*ones(samples, 1);

Iext = zeros(samples, 1);
Iext(10:20) = 50;


% membrane potential
Vm = zeros(samples, 1);  %mV
Vm(1) = Vreset;

%simulation
spikes = [];
refcounter = 0;
for i=2:samples
    
    if (refcounter > 0)
        Vm(i) = Vm(i-1);
        refcounter = refcounter-1;
    else
        dVm = Iext(i)/Cm;
        Vm(i) = Vm(i-1)+dVm;
    end
    
    % spike
    if (Vm(i) > Vth)
        Vm(i) = Vreset;
        spikes = [spikes t(i)];
        refcounter = tref/1000/sampling_time;
    end
end


% plotting
figure
if (~isempty(spikes))
    subplot(2, 1, 1);
end

plot(t, Vm);
xlabel('time (s)');
ylabel('V_m (mV)');
hold all;
plot(t, (Iext-min(Iext))/(max(Iext)-min(Iext))*(max(Vm)-min(Vm))+min(Vm));
hold off;

if (~isempty(spikes))
    subplot(2, 1, 2);
    LineFormatVert.LineWidth = 0.35;
    plotSpikeRaster({spikes}, ...
                    'PlotType', 'vertline', ...
                    'LineFormat', LineFormatVert, ...
                    'VertSpikePosition', -0.5, ...
                    'TimePerBin', 0.001, ...
                    'VertSpikeHeight', 0.7);
    xlabel('time (s)');
    xlim([0 simtime]);
end