import matplotlib
matplotlib.use("GTKAgg", warn=False, force=True)
import nest
from nest import raster_plot

# simulation parameters
T = 1000.0
gen_rate = 100.0
rule = {'rule': 'pairwise_bernoulli', 'p': 0.8}

# uniform spike generation
st = 0.1
spikes = []
while (st < T):
    spikes.append(st)
    st = st + 1000.0/gen_rate
ug = nest.Create('spike_generator', 100, {'spike_times': spikes})
n1 = nest.Create('iaf_neuron', 100)
nest.Connect(ug, n1, rule, {'weight': 10.0})

# poisson spike generation
pg = nest.Create('poisson_generator', 100, {'rate': gen_rate})
n2 = nest.Create('iaf_neuron', 100)
nest.Connect(pg, n2, rule, {'weight': 10.0})

# spike detector
sd = nest.Create('spike_detector', 1)
nest.Connect(ug, sd)
nest.Connect(n1, sd)
nest.Connect(pg, sd)
nest.Connect(n2, sd)

nest.Simulate(T)

raster_plot.from_device(sd)
raster_plot.show()