import matplotlib
matplotlib.use("GTKAgg", warn=False, force=True)
import nest
import pylab

# neuron parameters
neuron_params = {
	
	'V_reset': -70.0,
	'V_th':-55.0,
	'C_m': 250.0,
	't_ref': 2.0,
	'tau_m': 0.04 * 250,
	'E_L': -70.0

}

# create neuron
n = nest.Create('iaf_neuron', 100, neuron_params)

# external input current
cg = nest.Create('dc_generator', 1, {'amplitude': 400.0})
nest.Connect(cg, n, 'all_to_all', {'weight': 1.0, 'delay': 0.1})

# record membrane potential
ml = nest.Create('multimeter', 1, {'record_from': ['V_m']})
nest.Connect(ml, n)

# simulation
nest.Simulate(200)

# plot membrane potential
events = nest.GetStatus(ml)[0]["events"]
V_m = [x for (x,y) in zip(events["V_m"], events["senders"]) if y == n[0]]
pylab.plot(V_m)
pylab.axis([0, 200, -70, -55])
pylab.ylabel("membrane potential (mV)")
pylab.show()